@@ -5,7 +5,6 @@ import sympy
 
 from chempy import Substance
 from chempy import balance_stoichiometry
-from chempy import Equilibrium
 
 from math import isclose
 from math import floor, ceil
@@ -14,10 +13,11 @@ from chemsolve.element import Element
 from chemsolve.element import SpecialElement
 from chemsolve.utils.from_formula import determine_empirical_coef
 from chemsolve.utils.from_formula import determine_empirical, determine_molecular
-from chemsolve.utils.string_op import split
 from chemsolve.utils.constants import *
 from chemsolve.utils.warnings import RemovalWarning
 
+def split(string): return [char for char in string]
+
 try:
    import periodictable as pt
 except ModuleNotFoundError:
@@ -25,7 +25,6 @@ except ModuleNotFoundError:
 except ImportError:
    print("The module periodictable could not be found (may have not been installed).")
 
-
 class Compound(object):
    def __init__(self, compound, mol_comp = None, *args, **kwargs):
       if mol_comp: self.compound = mol_comp[0]; self.empirical = mol_comp[1]
@@ -35,6 +34,7 @@ class Compound(object):
       self.compound_elements = {}
       self.compound.elements = self.get_elements_in_compound()
       self.print_compound = Substance.from_formula(compound)
+      self.store_comp = compound
 
       '''
       The class can calculate quantities of moles and grams, depending on the specific keywords 'moles' and 'grams'.
