@@ -17,4 +17,16 @@ def RemovalWarning(future_version = current_version):
    Warning that a class or method will be removed in a future version.
    If a future version is not specified, then the current version is assumed.
    '''
-   warnings.warn(("The feature you are using will be removed following v" + str(future_version) + "."), DeprecationWarning)
\ No newline at end of file
+   warnings.warn(("The feature you are using will be removed following v" + str(future_version) + "."), DeprecationWarning)
+
+def assert_presence(initial, determiner):
+   '''
+   Determine if an item in one list is present in another list.
+   Used to confirm that a reactant is also present as a product.
+   '''
+   for item in initial:
+      if item not in determiner:
+         raise ValueError("A reactant must also be a product in a reaction.")
+
+
+
